# Copyright (c) 2016-2019, Thomas Hartmann
#
# This file is part of the OBOB Subject Database Project,
# see: https://gitlab.com/obob/obob_subjectdb/
#
#    obob_subjectdb is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    obob_subjectdb is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with obob_subjectdb. If not, see <http://www.gnu.org/licenses/>.


class DJANGO_AUTO_WEBASSETS_Settings(object):
    """Container for this modules settings including defaults."""

    defaults = {
        'WEBASSETS_JS_FOLDER': 'js_for_views',
        'WEBASSETS_PATH_TO_REQUIREJS': 'requirejs/require.js',
        'WEBASSETS_PATH_TO_REQUIREJS_CFG': 'requirejs_cfg.js',
        'WEBASSETS_SCRAMBLE_OUT_JS': False,
        'WEBASSETS_R_JS': 'node_modules/.bin/r.js',
        'WEBASSETS_OPTIMIZE': True,
    }

    def __init__(self):
        """Load our settings from django.conf.settings, applying defaults."""
        from django.conf import settings

        for name, default in self.defaults.items():
            value = getattr(settings, name, default)
            setattr(self, name, value)



# -*- coding: utf-8 -*-

import os.path
from codecs import open

from setuptools import setup, find_packages

REQUIRED = [
    'Django',
    'django-assets'
]

# find the location of this file
this_directory = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the README file
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

with open(os.path.join(this_directory, 'VERSION'), encoding='utf-8') as f:
    version = f.read()

setup(
    name='django-auto-webassets',
    version=version,
    packages=find_packages(),
    url='https://gitlab.com/thht_django/django-auto-webassets',
    license='GPLv3',
    author='Thomas Hartmann',
    author_email='thomas.hartmann@th-ht.de',
    description='Convenience Django Template Tags for handling javascript webassests',
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=REQUIRED,
    include_package_data=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    keywords='Django webassets'
)




# django-auto-webassets - Automatic webassets javascript bundles for django
# Copyright (C) 2019 Thomas Hartmann <thomas.hartmann@th-ht.de>
#
# This file is part of django-auto-webassets.
#
# django-auto-webassets is free software: you can redistribute it and/or
# modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# django-auto-webassets is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with django-auto-webassets.  If not, see
# <http://www.gnu.org/licenses/>.

import pytest
from django.core.management import call_command
from django.conf import settings
import subprocess
import shutil
import os
import seleniumbase


@pytest.fixture(scope='session', autouse=True)
def init_tests(tmpdir_factory):
    """General init fixture for all pytests."""
    settings.STATIC_ROOT = str(tmpdir_factory.mktemp('static'))
    node_modules_dir = str(tmpdir_factory.mktemp('node_modules'))
    shutil.copy(os.path.join(settings.BASE_DIR,
                             'django_auto_webassets/tests/package.json'),
                os.path.join(node_modules_dir))
    subprocess.run(['npm', 'update'], cwd=node_modules_dir)
    settings.STATICFILES_DIRS.append(
        os.path.join(node_modules_dir, 'node_modules'))
    settings.WEBASSETS_R_JS = os.path.join(
        node_modules_dir, 'node_modules', '.bin', 'r.js')
    call_command('collectstatic', interactive=False)
    yield


@pytest.fixture(scope='module')
def selenium():
    """Fixture returning a seleniumbase."""
    this_sel = seleniumbase.BaseCase('__init__')
    this_sel.setUp()
    yield this_sel
    this_sel.tearDown()
